@@ -28,4 +28,22 @@ def create_quantile_alphas(instances: pd.DataFrame, prediction_result: pd.DataFr
     alphas.loc[alphas["Prediction"] < low, "Signal"] = -1
     alphas.loc[alphas["Prediction"] > high, "Signal"] = 1
 
+    return alphas
+
+def create_absolute_prediction_alphas(instances: pd.DataFrame, prediction_result: pd.DataFrame) -> pd.DataFrame:
+    """
+    - use the prediction as alpha signal
+    """
+    assert len(prediction_result.columns) == 1, "prediction has more than one column"
+
+    alphas = prediction_result.copy()
+    alphas.columns = ["Prediction"]
+
+    alphas = alphas[alphas.index.isin(prediction_result.index)]
+    alphas = pd.concat([alphas, instances], axis=1)
+
+    # todo: just dropped na
+    alphas = alphas.dropna()
+
+    alphas["Signal"] = alphas["Prediction"]
     return alphas
\ No newline at end of file
