@@ -296,7 +296,7 @@ class ReturnsOperator(IndicatorOperator):
     def get_column_names():
         return ["Returns"]
 
-    def __init__(self, prefix, period, magnifier_multiplier=10000):
+    def __init__(self, prefix, period, magnifier_multiplier=100):
         self.prefix = prefix
         self.period = period
         self.magnifier_multiplier = magnifier_multiplier
@@ -392,6 +392,35 @@ class ForwardHighestReturn(IndicatorOperator):
 
         return data
 
+#################
+# return volatitliy
+##################
+
+class ReturnVarianceOperator(IndicatorOperator):
+    @staticmethod
+    def get_column_names():
+        return ["Return-Var"]
+
+    def __init__(self, prefix, period, magnifier_multiplier=100):
+        self.prefix = prefix
+        self.period = period
+        self.magnifier_multiplier = magnifier_multiplier
+
+    def apply(self, data: IndicatorData) -> IndicatorData:
+        logger = logging.getLogger(__name__)
+        logger.info("Returns variances =================================")
+        result_col_prefix = self.prefix
+        close_prices = data["Close"]
+
+        res_col = self.calculate_final_column_name(prefix=self.prefix, col_name=self.get_column_names()[0], period=self.period)
+        # Todo magnifier= 1 for now but returns so small
+        # Todo: pct change fore return can be params
+        data["_temp"] = close_prices.pct_change(1)
+        data[res_col] = data["_temp"].rolling(self.period).std() * self.magnifier_multiplier
+        _ = data.pop("_temp")
+        return data
+
+
 
 ##############
 # lags
