@@ -6,6 +6,7 @@ import moosir_feature.transformers.basic_features.feature_calculator as f_basic
 import moosir_feature.transformers.indicators.feature_manager as f_indicator
 import moosir_feature.transformers.feature_selections.feature_selector as f_selector
 import moosir_feature.transformers.features_common.calculator as f_common
+import moosir_feature.transformers.signal_features.feature_manager as f_sig
 
 from .settings import *
 
@@ -37,6 +38,17 @@ def _create_targets(clean_data: pd.DataFrame,
             feature_name=target_settings.target_col_feature_subtype,
             columns=target_eng.columns, is_fwd=True)
 
+    elif type(target_settings).__name__ == SignalTargetSettings.__name__:
+        target_eng = f_sig.calculate_forwards(ohlc=clean_data,
+                                                win_lens=[target_settings.win_len],
+                                                feature_names=[target_settings.feature_name],
+                                                forward_lens=[target_settings.lookahead_len])
+
+        target_col = f_sig.get_feature_col_by_subtype_name(
+            feature_name=target_settings.target_col_feature_subtype,
+            columns=target_eng.columns,
+            is_fwd=True)
+
     if len(target_eng) == 0:
         return target_eng
 
@@ -57,6 +69,10 @@ def _create_features(clean_data: pd.DataFrame, feature_settings: FeatureSettings
     elif type(feature_settings).__name__ == BasicFeatureSettings.__name__:
         features_eng = f_basic.calculate_features(ohlc=features_eng,
                                                   feature_names=feature_settings.feature_names)
+    elif type(feature_settings).__name__ == SignalFeatureSettings.__name__:
+        features_eng = f_sig.calculate_features(ohlc=features_eng, win_lens=feature_settings.win_lens,
+                                                    feature_names=feature_settings.feature_names)
+
     else:
         raise Exception(f"feature calculator is not implemented: {type(feature_settings).__name__}")
 
@@ -78,6 +94,10 @@ def _create_lags(ohlc: pd.DataFrame,
         feature_lags = f_indicator.calculate_lags(ohlc=ohlc, win_lens=lag_settings.win_lens,
                                                   lag_lens=lag_settings.lag_lens,
                                                   feature_names=lag_settings.feature_names)
+    elif type(lag_settings).__name__ == SignalLagSettings.__name__:
+        feature_lags = f_sig.calculate_lags(ohlc=ohlc, win_lens=lag_settings.win_lens,
+                                                  lag_lens=lag_settings.lag_lens,
+                                                  feature_names=lag_settings.feature_names)
 
     return feature_lags
 
@@ -168,6 +188,8 @@ class FeatureCreatorManager:
         features_lags = _create_lags_list(data=clean_data.copy(),
                                           lag_settings_list=self.lag_settings_list)
 
+        if len(features) != 0 and len(features_lags) != 0:
+            assert not bool(set(features.columns) & set(features_lags.columns)), "features and lag features have common features"
 
         features = f_common.combine_features(features_list=[features_lags, features])
 
