@@ -43,14 +43,26 @@ def _get_target_settings(setting_key: str):
         'target_col_feature_type': 'Return',
         'target_col_feature_subtype': MaxPriceAndReturn.get_column_names()[1],
     })
-    settings = {"returns": returns, "max_returns": max_returns}
+
+    var_returns = IndicatorTargetSettings(**{
+        'win_len': 80,
+        'lookahead_len': 3,
+        'feature_name': ReturnVarianceOperator.__name__,
+        'target_col_feature_type': 'Return-Var',
+        'target_col_feature_subtype': ReturnVarianceOperator.get_column_names()[0],
+    })
+
+    settings = {"returns": returns, "max_returns": max_returns, "var_returns": var_returns}
     return settings[setting_key]
 
 
 def _get_feature_settings(setting_key: str):
     ind = IndicatorFeatureSettings(**{
         'win_lens': [70],
-        'feature_names': [ReturnsOperator.__name__, MaxPriceAndReturn.__name__, MinPriceAndReturn.__name__]
+        'feature_names': [ReturnsOperator.__name__,
+                          MaxPriceAndReturn.__name__,
+                          MinPriceAndReturn.__name__,
+                          ReturnVarianceOperator.__name__]
     })
 
     settings = {"ind": ind}
@@ -61,7 +73,10 @@ def _get_lag_settings(setting_key: str):
     ind = IndicatorLagSettings(**{'feature_parameters':
         {
             'win_lens': [30],
-            'feature_names': [ReturnsOperator.__name__, MaxPriceAndReturn.__name__, MinPriceAndReturn.__name__]
+            'feature_names': [ReturnsOperator.__name__,
+                              MaxPriceAndReturn.__name__,
+                              MinPriceAndReturn.__name__,
+                              ReturnVarianceOperator.__name__]
         },
         'lag_lens': [3]
     })
@@ -174,3 +189,32 @@ def test_feature_manager_calculate_max_returns_targets(ohlc: pd.DataFrame):
 
     # assert lags
     _assert_indicator_lags(features=features, context=context, lag_settings_list=lag_settings_list)
+
+def test_feature_manager_calculate_var_returns_features(ohlc: pd.DataFrame):
+    # arrange
+    target_settings = _get_target_settings("var_returns")
+    feature_settings_list = [_get_feature_settings("ind")]
+    lag_settings_list = [_get_lag_settings("ind")]
+
+    # act
+    features, targets, all = _run_manager(ohlc=ohlc,
+                                          target_settings=target_settings,
+                                          feature_settings_list=feature_settings_list,
+                                          lag_settings_list=lag_settings_list)
+
+    _print(features, targets, all)
+    # assert
+    context = Context()
+
+    # assert features
+    _assert_indicator_features(features=features, context=context, feature_settings_list=feature_settings_list)
+
+    # assert targets
+    fwd_ops = _get_indicator_operators([target_settings.feature_name])
+    assert context.validate(targets,
+                            operators=fwd_ops,
+                            periods=[target_settings.win_len],
+                            forward_periods=[target_settings.lookahead_len])
+
+    # assert lags
+    _assert_indicator_lags(features=features, context=context, lag_settings_list=lag_settings_list)
\ No newline at end of file
